# SQL-Cable

## What is SQL-Cable?
SQL-Cable is package designed to make it easier to work with a flask app and sqlite3 database.

## How do I use SQL-Cable?
You can read the [docs](docs_link).

## How do I install SQL-Cable?
if you are on windows all you have to do is put `pip install sql-cable` in to your cmd or PowerShell and it will do the rest.
